@@ -57,7 +57,7 @@ def is_commit_in_stack(sha: str, tip: str = None, base: str = BASE_TAG):
     Returns if the commit is not in the range specified.
     """
     repo = Repo(REPO_PATH)
-    commits = list(repo.iter_commits(f"{base}..{tip}"))
+    commits = list(repo.iter_commits(f"{base}^..{tip}"))
     target_commit = get_commit_safe(sha)
     if not target_commit:
         return False
