@@ -43,6 +43,13 @@ option_create = typer.Option(
     False, "--create", "-c",
     help='When submitting, use this flag if you wish to create new diffs instead ' +
     'of updating the attached ones')
+option_no_link = typer.Option(
+    False,
+    "--no-link", "-nl",
+    help='When turned on, no link will be displayed with the commit summary, ' +
+    'leaving you a more succinct overview of the stack. You could also configure ' +
+    r'your terminal (smart selection in iTerm2) to detect diff ID ({D\d+} for example) ' +
+    'and convert it into a clickable link.')
 
 
 @app.command()
@@ -217,7 +224,7 @@ def edit(sha: Optional[str] = arg_sha,
 
 
 @app.command()
-def show(base: str = option_base):
+def show(base: str = option_base, no_link: bool = option_no_link):
     """
     Prints the stack.
     """
@@ -225,11 +232,15 @@ def show(base: str = option_base):
     repo = Repo(REPO_PATH)
     commits = list(repo.iter_commits(f"{base}..HEAD"))
     if not commits:
-        print(display_utils._yellow('No commits in the stack.'))
+        print(display_utils.yellow('No commits in the stack.'))
     else:
         phab_utils.fetch_matadata_from_commits(*commits)
     for i, commit in enumerate(commits):
         print(('| ' if i > 0 else '↑ ') + display_utils.commit_summary(commit, short=False))
+        if not no_link:
+            print('| ' + 5 * ' ' +
+                  display_utils.underline(display_utils.blue(phab_utils.get_diff_link(commit))))
+            print('| ')
     display_utils.print_base(base, repo.commit(f"{base}"))
 
 
