@@ -17,6 +17,10 @@ STATUS_CODE_ACCEPTED = 2
 
 
 def _get_phab_uri() -> str:
+    """Gets phabricator.uri from .arcconfig; Throws if no file found. 
+    Note: since all .arcconfigs requries the uri field, this method doesn't account 
+    for the lack of it.
+    """
     try:
         with open(PHABRICATOR_CONFIG_PATH, "r", encoding="utf-8") as arc_cfg_file:
             data = json.load(arc_cfg_file)
@@ -41,6 +45,13 @@ def get_diff_id(commit_id: str = "", pure_id: bool = False) -> str:
     return diff_id[(1 if pure_id else 0):]
 
 
+def get_diff_link(cmt: Commit) -> str:
+    """Gets and returns the url of the given commit, empty if no diff is attached"""
+    diff_id = get_diff_id(cmt) if has_diff_attached(cmt) else ""
+    phabricator_uri = _get_phab_uri()
+    return phabricator_uri + diff_id if diff_id and phabricator_uri else "----"
+
+
 def add_parent_to_diff(diff_id: str, parent_diff_id: str):
     """Adds the parent diff as the parent diff for the given diff_id"""
     parent_phid = _get_phid_from_diff_id(parent_diff_id)
